searchData={"items":[{"type":"module","title":"ExDbug","doc":"Advanced debug utility for debugging and analysis, inspired by the Node.js 'debug' package.","ref":"ExDbug.html"},{"type":"module","title":"Usage - ExDbug","doc":"Add `use ExDbug, context: :my_namespace` to a module, and use `dbug/1` or `error/1` to log debug or error messages.\n\nDebug output is controlled by:\n  - The `:enabled` config key for `:ex_dbug` (compile-time)\n  - The `DEBUG` environment variable (runtime), which determines which namespaces are displayed","ref":"ExDbug.html#module-usage"},{"type":"module","title":"Enabling/Disabling at Compile Time - ExDbug","doc":"In your `config.exs`:\n```elixir\nconfig :ex_dbug, enabled: true\n```\nIf `enabled: false`, calls to `dbug` and `error` are compiled out (no runtime overhead).","ref":"ExDbug.html#module-enabling-disabling-at-compile-time"},{"type":"module","title":"Using DEBUG Environment Variable - ExDbug","doc":"Set `DEBUG` to enable certain namespaces:\n  - `DEBUG=\"*\"` enables all namespaces\n  - `DEBUG=\"myapp:*\"` enables all namespaces starting with myapp:\n  - `DEBUG=\"*,-myapp:db\"` enables all but myapp:db\n\nYou can separate multiple patterns with commas. A leading `-` excludes a pattern.\n\nExample:\n```bash\nDEBUG=\"myapp:*\" mix run\n```","ref":"ExDbug.html#module-using-debug-environment-variable"},{"type":"module","title":"Example - ExDbug","doc":"```elixir\ndefmodule MyModule do\n  use ExDbug, context: :my_feature\n\n  def run do\n    dbug(\"Starting run\")\n    :ok\n  end\nend\n```\nIf `DEBUG=\"my_feature\"`, calling `MyModule.run()` will log the debug message.","ref":"ExDbug.html#module-example"},{"type":"module","title":"Features - ExDbug","doc":"- Namespace-based enabling/disabling of debug output\n  - Compile-time toggle to remove debug calls entirely\n  - Stack trace or timing info can be integrated if desired\n  - Works similar to the Node.js 'debug' library","ref":"ExDbug.html#module-features"},{"type":"macro","title":"ExDbug.dbug/3","doc":"","ref":"ExDbug.html#dbug/3"},{"type":"macro","title":"ExDbug.error/3","doc":"","ref":"ExDbug.html#error/3"},{"type":"function","title":"ExDbug.format_output/2","doc":"Format output by prefixing with [Namespace].","ref":"ExDbug.html#format_output/2"},{"type":"function","title":"ExDbug.get_debug_enabled/1","doc":"Check if debug is enabled based on application config.","ref":"ExDbug.html#get_debug_enabled/1"},{"type":"function","title":"ExDbug.log/4","doc":"Logging logic:\nWe determine if we should log by checking:\n1. If the level is allowed\n2. If the context matches DEBUG patterns","ref":"ExDbug.html#log/4"},{"type":"function","title":"ExDbug.matches_namespace?/2","doc":"Check if a namespace matches any of the included patterns and is not excluded.\nIf no patterns are set, default to enable if the library is enabled.","ref":"ExDbug.html#matches_namespace?/2"},{"type":"function","title":"ExDbug.merge_options/1","doc":"Merge options from app config, defaults, and module opts.","ref":"ExDbug.html#merge_options/1"},{"type":"function","title":"ExDbug.namespace_enabled?/1","doc":"Check if a given namespace (context) is enabled by the DEBUG environment variable.\nIf DEBUG is unset or empty, default to enabling everything if :enabled is true,\notherwise no logging.","ref":"ExDbug.html#namespace_enabled?/1"},{"type":"function","title":"ExDbug.parse_debug_env/0","doc":"Parse the DEBUG environment variable for enable/disable patterns.\n\nReturns a tuple {includes, excludes}, where includes and excludes are lists of patterns.\nA pattern can have wildcards (*).","ref":"ExDbug.html#parse_debug_env/0"},{"type":"macro","title":"ExDbug.track/2","doc":"","ref":"ExDbug.html#track/2"},{"type":"function","title":"ExDbug.wildcard_match?/2","doc":"Perform a simple wildcard match.\n\n* matches any sequence of characters.","ref":"ExDbug.html#wildcard_match?/2"},{"type":"type","title":"ExDbug.debug_opts/0","doc":"","ref":"ExDbug.html#t:debug_opts/0"},{"type":"extras","title":"ExDbug","doc":"# ExDbug\n\nA lightweight, namespace-based debugging utility for Elixir, inspired by Node.js's \"debug\" library. ExDbug enables contextual logging with zero production overhead and runtime-configurable output.","ref":"readme.html"},{"type":"extras","title":"Features - ExDbug","doc":"- Toggle debug output dynamically via environment variables\n- Zero overhead in production builds through compile-time optimization\n- Namespace-based log filtering with wildcard support \n- Rich contextual debugging messages\n- Seamless value tracking across function chains\n- Designed for both human debugging and LLM-assisted development","ref":"readme.html#features"},{"type":"extras","title":"Installation - ExDbug","doc":"Add `ex_dbug` to your dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_dbug, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThen run:\n\n```bash\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - ExDbug","doc":"","ref":"readme.html#configuration"},{"type":"extras","title":"Compile-time Settings - ExDbug","doc":"Configure ExDbug in your `config.exs` (or environment-specific config):\n\n```elixir\nconfig :ex_dbug,\n  enabled: true  # Set to false to compile out debug statements\n```","ref":"readme.html#compile-time-settings"},{"type":"extras","title":"Runtime Control - ExDbug","doc":"Control debug output using the `DEBUG` environment variable:\n\n```bash\n# Enable all debug output\nDEBUG=\"*\" mix run\n\n# Enable specific namespace\nDEBUG=\"myapp:specific\" mix run\n\n# Enable all except specific namespace\nDEBUG=\"*,-myapp:secret\" mix run\n```\n\nPattern syntax:\n- `*` - Enable all namespaces\n- `myapp:*` - Enable all namespaces starting with `myapp:`\n- `*,-myapp:db` - Enable all except `myapp:db`\n- Multiple patterns can use commas or spaces as separators","ref":"readme.html#runtime-control"},{"type":"extras","title":"Usage - ExDbug","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Basic Debugging - ExDbug","doc":"```elixir\ndefmodule MyModule do\n  use ExDbug, context: :my_namespace\n\n  def my_function do\n    dbug(\"Starting my_function\")\n    # Your code here\n    error(\"An error occurred\")  # Logs error-level message\n  end\nend\n```","ref":"readme.html#basic-debugging"},{"type":"extras","title":"Value Tracking - ExDbug","doc":"```elixir\ndefmodule MyCalculations do\n  use ExDbug, context: :my_calculations\n\n  def compute do\n    track(1 + 2, \"sum_of_1_and_2\")  # Logs and returns the computed value\n  end\nend\n```","ref":"readme.html#value-tracking"},{"type":"extras","title":"LLM-Assisted Development - ExDbug","doc":"ExDbug enhances AI-assisted development by providing detailed execution traces that help language models:\n\n- Understand complex call paths\n- Debug concurrent operations\n- Generate accurate Elixir code\n- Analyze runtime behavior\n\nThe detailed logs and namespace organization make it easier for AI tools to interpret program flow and state changes.","ref":"readme.html#llm-assisted-development"},{"type":"extras","title":"Contributing - ExDbug","doc":"1. Fork the repository\n2. Create a feature branch\n3. Add tests for your changes\n4. Submit a pull request","ref":"readme.html#contributing"},{"type":"extras","title":"License - ExDbug","doc":"Released under the MIT License. See [LICENSE](LICENSE) for details.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}